@@ -41,3 +41,43 @@ sub new {
 }
 
 1;
+
+__END__
+
+=head1 NAME
+
+Gtk2::Ex::FormFactory::Loader - Dynamic loading of FormFactory modules
+
+=head1 SYNOPSIS
+
+No synposis, internally used by Gtk2::Ex::FormFactory.
+
+=head1 DESCRIPTION
+
+This class implements dynamic loading of Gtk2::Ex::FormFactory
+widget classes and has no external interface.
+
+=head1 AUTHORS
+
+ Jrn Reder <joern at zyn dot de>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 2004-2005 by Jrn Reder.
+
+This library is free software; you can redistribute it and/or modify
+it under the terms of the GNU Library General Public License as
+published by the Free Software Foundation; either version 2.1 of the
+License, or (at your option) any later version.
+
+This library is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+Library General Public License for more details.
+
+You should have received a copy of the GNU Library General Public
+License along with this library; if not, write to the Free Software
+Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307
+USA.
+
+=cut
